package com.kakao.sdk.link.sample.events;

import android.app.Activity;
import android.os.Bundle;
import android.view.View;
import android.widget.TextView;
import android.widget.Toast;

import com.kakao.events.Event;
import com.kakao.events.EventsLogResponse;
import com.kakao.events.EventsService;
import com.kakao.network.ErrorResult;
import com.kakao.network.callback.ResponseCallback;
import com.kakao.sdk.link.sample.R;
import com.kakao.sdk.link.sample.common.widget.KakaoToast;
import com.kakao.util.helper.log.Logger;

import java.util.Date;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

public class EventsMainActivity extends Activity implements View.OnClickListener{
    private final String to = "http://www.kakaocorp.com";
    private final String action = "click";

    private Map<String, Object> props;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.layout_events_main);
        ((TextView) findViewById(R.id.text_title)).setText(R.string.text_events);
        findViewById(R.id.title_back).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                finish();
            }
        });
    }

    @Override
    public void onClick(View view) {
        switch (view.getId()) {
            case R.id.publish_event_button:
                logOneEvent();
                break;
            case R.id.publish_multiple_events_button:
                logMultipleEvents();
                break;
            case R.id.add_event_to_batch_button:
                addEventToBatch();
        }
    }

    private void logOneEvent() {
        props = new HashMap<String, Object>();
        props.put("customkey1", "value1");
        props.put("customkey2", "value2");
        Event rootEvent = new Event.Builder().setTimestamp(new Date().getTime()).setTo(to).setAction(action).setProps(props).build();
        EventsService.logSingleEvent(getApplicationContext(), rootEvent, new ResponseCallback<EventsLogResponse>() {
            @Override
            public void onFailure(ErrorResult errorResult) {
                Logger.e("failure");
                Logger.e(errorResult.toString());
            }

            @Override
            public void onSuccess(EventsLogResponse result) {
                Logger.e("success: " + result.getSuccessCount());
                KakaoToast.makeToast(getApplicationContext(), "Successfully published " + result.getSuccessCount() + " event.", Toast.LENGTH_LONG).show();
            }
        });
    }

    private void logMultipleEvents() {
        EventsService.logBatchedEvents(this, new ResponseCallback<EventsLogResponse>() {
            @Override
            public void onFailure(ErrorResult errorResult) {
                Logger.e("failure");
                Logger.e(errorResult.toString());
            }

            @Override
            public void onSuccess(EventsLogResponse result) {
                Logger.e("success: " + result.getSuccessCount());
                KakaoToast.makeToast(getApplicationContext(), "Successfully published " + result.getSuccessCount() + " events.", Toast.LENGTH_LONG).show();
            }
        });
    }

    private void addEventToBatch() {
        props = new HashMap<String, Object>();
        props.put("customkey1", "value1");
        props.put("customkey2", "value2");

        Event event = new Event.Builder().setTimestamp(new Date().getTime()).setTo(to).setAction(action).setProps(props).build();
        EventsService.addEventToBatch(this, event, new ResponseCallback<Integer>() {
            @Override
            public void onFailure(ErrorResult errorResult) {
                Logger.e("Failed to add the event to batch.");
            }

            @Override
            public void onSuccess(Integer result) {
                KakaoToast.makeToast(getApplicationContext(), "Successfully added an event to batch. Current batch size is " + result + ".", Toast.LENGTH_LONG).show();
            }
        });
    }
}